@@ -138,7 +138,7 @@
 #include "player.h"
 #include "unit.h"
 #if defined(DEBUG) && defined(TIMEIT)
-#include "rdtsc.h"
+//#include "rdtsc.h"
 #endif
 
 #include "ai_local.h"
