@@ -219,7 +219,6 @@ extern int getopt(int argc, char *const*argv, const char *opt);
 #include "commands.h"
 #include "campaign.h"
 #include "editor.h"
-#include "movie.h"
 
 #ifdef DEBUG
 extern SCM CclUnits(void);
@@ -494,57 +493,6 @@ local void WaitCallbackExit(void)
     DebugLevel3Fn("Exit\n");
 }
 
-#if 0
-
-/**
-**	Test some video effects.
-**
-**	@param frame	Current frame.
-*/
-local void VideoEffect0(int frame, const EventCallback* callbacks)
-{
-    int i;
-    static Graphic* Logo;
-
-    //
-    //	Cleanup
-    //
-    if( frame==-1 ) {
-	VideoFree(Logo);
-	Logo=NULL;
-	return;
-    }
-
-    //
-    //	Inititialize
-    //
-    if( !Logo ) {
-	Logo=LoadSprite("freecraft.png",628,141);
-    }
-    VideoLockScreen();
-
-    switch( VideoDepth ) {
-	case 15:
-	case 16:
-	    for( i=0; i<VideoWidth*VideoHeight; ++i ) {
-		int j;
-
-		j=MyRand()&0x1F;
-		VideoMemory16[i]=(j<<11)|(j<<6)|(j);
-	    }
-	    break;
-    }
-
-    VideoDrawTextCentered(VideoWidth/2,5,LargeFont,"Press SPACE to continue.");
-    VideoDraw(Logo,0,(VideoWidth-VideoGraphicWidth(Logo))/2,50);
-
-    VideoUnlockScreen();
-
-    Invalidate();
-    RealizeVideoMemory();
-}
-
-#endif
 
 /**
 **	Draw video effect circle.
@@ -613,241 +561,6 @@ global void EffectDrawCircle(int* ptr,int depth,int x,int y,int r)
     } while( cx <= cy );
 }
 
-/**
-**	Test some video effects.
-**
-**	@param frame		Current frame.
-**	@param callbacks	Call backs that handle events.
-*/
-#ifdef USE_OPENGL
-local void VideoEffect0(int frame __attribute__((unused)),
-	const EventCallback* callbacks __attribute__((unused)))
-{
-}
-
-#else
-
-local void VideoEffect0(int frame,
-	const EventCallback* callbacks __attribute__((unused)))
-{
-    static int* buf1;
-    static int* buf2;
-    static void* vmem;
-    int* tmp;
-    int x;
-    int y;
-
-    //
-    //	Cleanup
-    //
-    if( frame==-1 ) {
-	free(buf1);
-	free(buf2);
-	free(vmem);
-	vmem=buf1=buf2=NULL;
-	return;
-    }
-
-    //
-    //	Inititialize
-    //
-    if( !buf1 ) {
-	buf1=calloc(VideoWidth*VideoHeight,sizeof(int));
-	buf2=calloc(VideoWidth*VideoHeight,sizeof(int));
-	VideoLockScreen();
-	switch( VideoBpp ) {
-	    case 15:
-	    case 16:
-		vmem=malloc(VideoWidth*VideoHeight*sizeof(VMemType16));
-		memcpy(vmem,VideoMemory,VideoWidth*VideoHeight*sizeof(VMemType16));
-		break;
-	    case 24:
-		vmem=malloc(VideoWidth*VideoHeight*sizeof(VMemType24));
-		memcpy(vmem,VideoMemory,VideoWidth*VideoHeight*sizeof(VMemType24));
-		break;
-	    case 32:
-		vmem=malloc(VideoWidth*VideoHeight*sizeof(VMemType32));
-		memcpy(vmem,VideoMemory,VideoWidth*VideoHeight*sizeof(VMemType32));
-		break;
-	}
-	VideoUnlockScreen();
-
-	if( 1 ) {
-	    for( y=1; y<VideoHeight-1; y+=16 ) {
-		for( x=1; x<VideoWidth-1; x+=16 ) {
-		    buf1[y*VideoWidth+x] = (rand()%10)*20;
-		}
-	    }
-	}
-	if( 0 ) {
-	    for( x=1; x<VideoWidth-1; ++x ) {
-		buf2[(VideoHeight-1)*VideoWidth+x] = !(x%20)*-100;
-	    }
-	}
-    }
-
-    //
-    //	Generate waves
-    //
-    for( y=1; y<VideoHeight-1; ++y ) {
-	for( x=1; x<VideoWidth-1; ++x ) {
-	    int i;
-
-	    i = ((buf1[y*VideoWidth+x-1]+
-		buf1[y*VideoWidth+x+1]+
-		buf1[y*VideoWidth-VideoWidth+x]+
-		buf1[y*VideoWidth+VideoWidth+x])>>1) - buf2[y*VideoWidth+x];
-	    buf2[y*VideoWidth+x] = i - (i >> 7);
-	}
-    }
-
-    //
-    //	Add mouse
-    //
-    if( WaitMouseY && WaitMouseX
-	    && WaitMouseX!=VideoWidth-1 && WaitMouseY!=VideoHeight-1 ) {
-	EffectDrawCircle(buf2,10,WaitMouseX,WaitMouseY,10);
-	//buf2[WaitMouseY*VideoWidth+WaitMouseX]-=100;
-    }
-    //
-    //	Random drops
-    //
-    if( 0 ) {
-	EffectDrawCircle(buf2,20,rand()%(VideoWidth-1),rand()%(VideoHeight-1),
-	    rand()%7);
-    }
-
-    //
-    //	Draw it
-    //
-    VideoLockScreen();
-    for( y=1; y<VideoHeight-1; ++y ) {
-#ifdef WITH_ARTSC
-	if (ArtsGetSpace() >= 1024) {
-	    callbacks->SoundReady();
-	}
-#endif
-	for( x=1; x<VideoWidth-1; ++x ) {
-	    int xo;
-	    int yo;
-	    int xt;
-	    int yt;
-	    VMemType16 pixel16;
-	    VMemType24 pixel24;
-	    VMemType32 pixel32;
-
-	    xo=buf2[y*VideoWidth+x-1] - buf2[y*VideoWidth+x+1];
-	    yo=buf2[y*VideoWidth-VideoWidth+x] -
-		    buf2[y*VideoWidth+VideoWidth+x];
-
-	    xt=x+xo;
-	    if( xt<0 ) {
-		xt=0;
-	    } else if( xt>=VideoWidth ) {
-		xt=VideoWidth-1;
-	    }
-	    yt=y+yo;
-	    if( yt<0 ) {
-		yt=0;
-	    } else if( yt>=VideoHeight ) {
-		yt=VideoHeight-1;
-	    }
-
-	    switch( VideoDepth ) {
-		case 15:
-		    pixel16=((VMemType16*)vmem)[xt+yt*VideoWidth];
-		    if( xo ) {		// Shading
-			int r,g,b;
-
-			r=(pixel16>>0)&0x1F;
-			g=(pixel16>>5)&0x1F;
-			b=(pixel16>>10)&0x1F;
-			r+=xo;
-			g+=xo;
-			b+=xo;
-			r= r<0 ? 0 : r>0x1F ? 0x1F : r;
-			g= g<0 ? 0 : g>0x1F ? 0x1F : g;
-			b= b<0 ? 0 : b>0x1F ? 0x1F : b;
-			pixel16=r|(g<<5)|(b<<10);
-		    }
-		    VideoMemory16[x+VideoWidth*y]=pixel16;
-		    break;
-		case 16:
-		    pixel16=((VMemType16*)vmem)[xt+yt*VideoWidth];
-		    if( xo ) {		// Shading
-			int r,g,b;
-
-			r=(pixel16>>0)&0x1F;
-			g=(pixel16>>5)&0x3F;
-			b=(pixel16>>11)&0x1F;
-			r+=xo;
-			g+=xo*2;
-			b+=xo;
-			r= r<0 ? 0 : r>0x1F ? 0x1F : r;
-			g= g<0 ? 0 : g>0x3F ? 0x3F : g;
-			b= b<0 ? 0 : b>0x1F ? 0x1F : b;
-			pixel16=r|(g<<5)|(b<<11);
-		    }
-		    VideoMemory16[x+VideoWidth*y]=pixel16;
-		    break;
-		case 24:
-		    if( VideoBpp==24 ) {
-			pixel24=((VMemType24*)vmem)[xt+yt*VideoWidth];
-			if( xo ) {
-			    int r,g,b;
-
-			    r=(pixel24.a)&0xFF;
-			    g=(pixel24.b)&0xFF;
-			    b=(pixel24.c)&0xFF;
-			    r+=xo<<3;
-			    g+=xo<<3;
-			    b+=xo<<3;
-			    r= r<0 ? 0 : r>0xFF ? 0xFF : r;
-			    g= g<0 ? 0 : g>0xFF ? 0xFF : g;
-			    b= b<0 ? 0 : b>0xFF ? 0xFF : b;
-			    pixel24.a=r;
-			    pixel24.b=g;
-			    pixel24.c=b;
-			}
-			VideoMemory24[x+VideoWidth*y]=pixel24;
-			break;
-		    }
-		    // FALL THROUGH
-		case 32:
-		    pixel32=((VMemType32*)vmem)[xt+yt*VideoWidth];
-		    if( xo ) {
-			int r,g,b;
-
-			r=(pixel32>>0)&0xFF;
-			g=(pixel32>>8)&0xFF;
-			b=(pixel32>>16)&0xFF;
-			r+=xo<<3;
-			g+=xo<<3;
-			b+=xo<<3;
-			r= r<0 ? 0 : r>0xFF ? 0xFF : r;
-			g= g<0 ? 0 : g>0xFF ? 0xFF : g;
-			b= b<0 ? 0 : b>0xFF ? 0xFF : b;
-			pixel32=r|(g<<8)|(b<<16);
-		    }
-		    VideoMemory32[x+VideoWidth*y]=pixel32;
-		    break;
-	    }
-	}
-    }
-    VideoUnlockScreen();
-
-    Invalidate();
-    RealizeVideoMemory();
-
-    //
-    //	Swap buffers
-    //
-    tmp=buf1;
-    buf1=buf2;
-    buf2=tmp;
-}
-#endif
-
 #ifdef _DEBUG
 /**
 **	Draw the fonts, for screen shots.
@@ -889,75 +602,6 @@ local void DebugDrawFonts(void)
 }
 #endif
 
-/**
-**	Wait for any input.
-**
-**	@param timeout	Time in seconds to wait.
-*/
-local void WaitForInput(int timeout)
-{
-    EventCallback callbacks;
-#ifdef linux
-    char* s;
-    char ddate[72+1];
-    FILE* ddfile;
-#endif
-
-    SetVideoSync();
-
-    callbacks.ButtonPressed=WaitCallbackKey;
-    callbacks.ButtonReleased=WaitCallbackKey;
-    callbacks.MouseMoved=WaitCallbackMouse;
-    callbacks.MouseExit=WaitCallbackExit;
-    callbacks.KeyPressed=WaitCallbackKey2;
-    callbacks.KeyReleased=WaitCallbackKey2;
-    callbacks.KeyRepeated=WaitCallbackKey3;
-    callbacks.NetworkEvent=NetworkEvent;
-    callbacks.SoundReady=WriteSound;
-
-    //
-    //	FIXME: more work needed, scrolling credits, animations, ...
-#ifdef _DEBUG
-    WaitNoEvent=1;
-    while( WaitNoEvent ) {
-	DebugDrawFonts();
-	WaitEventsOneFrame(&callbacks);
-    }
-#else
-    VideoLockScreen();
-    //VideoDrawTextCentered(VideoWidth/2,5,LargeTitleFont,"Press SPACE to continue.");
-    VideoDrawTextCentered(VideoWidth/2,5,LargeFont,"Press SPACE to continue.");
-#ifdef linux
-    ddate[0]='\0';
-    ddfile=popen("`which ddate`","r");
-    fgets(ddate,72,ddfile);
-    pclose(ddfile);
-    if( (s=strrchr(ddate,'\n')) ) {
-	*s='\0';
-    }
-    VideoDrawTextCentered(VideoWidth/2,20,LargeFont,ddate);
-#endif
-    VideoUnlockScreen();
-    Invalidate();
-    RealizeVideoMemory();
-
-    WaitNoEvent=1;
-    timeout*=CYCLES_PER_SECOND;
-    while( timeout-- && WaitNoEvent ) {
-	VideoEffect0(timeout, &callbacks);
-	WaitEventsOneFrame(&callbacks);
-    }
-    VideoEffect0(-1, &callbacks);
-#endif
-
-    VideoLockScreen();
-    VideoDrawTextCentered(VideoWidth/2,5,LargeFont,
-	"----------------------------");
-    VideoUnlockScreen();
-    Invalidate();
-    RealizeVideoMemory();
-
-}
 
 /**
 **	Show load progress.
@@ -1152,7 +796,6 @@ local void PrintHeader(void)
 #ifdef USE_LIBMODPLUG
     "\n  libmodplug Copyright by Kenton Varda & Olivier Lapique."
 #endif
-    "\n  VP3 codec Copyright by On2 Technologies Inc."
 #ifdef USE_SDL
     "\n  SDL Copyright by Sam Lantinga."
 #endif
@@ -1270,28 +913,9 @@ Use it at your own risk.\n\n");
     srand(time(NULL));			// Random counter = random each start
 #endif
 
-    InitMovie();
-
-    //
-    //	Show title screen.
-    //
-    i=1;
     SetClipping(0,0,VideoWidth-1,VideoHeight-1);
-    if( TitleScreen ) {
-	if( (i=PlayMovie(TitleScreen,
-		PlayMovieZoomScreen|PlayMovieKeepAspect)) ) {
-	    DisplayPicture(TitleScreen);
-	    Invalidate();
-	}
-    }
-
     InitUnitsMemory();		// Units memory management
     PreMenuSetup();		// Load everything needed for menus
-
-    if( i ) {
-	WaitForInput(20);		// Show game intro
-    }
-
     MenuLoop(MapName,&TheMap);	// Enter the menu loop
 
     return 0;
@@ -1334,8 +958,6 @@ global volatile void Exit(int err)
     CleanFonts();
 #endif
 
-    CleanMovie();
-
     fprintf(stderr,"Thanks for playing FreeCraft.\n");
     exit(err);
 }
@@ -1393,6 +1015,13 @@ map is relative to FreeCraftLibPath=datapath, use ./map for relative to cwd\n\
 */
 global int main(int argc,char** argv)
 {
+   /* Once fullscreen and windowed mode flags are overidden when
+    * configuration is loaded, I've created these new flags to be used
+    * *after* loading configuration to ensure that -F and -W arguments
+    * will be considered when passed in command line */
+   int ForceFullScreen = 0;
+   int ForceWindowed = 0;
+
 #ifdef USE_BEOS
     //
     //	Parse arguments for BeOS
@@ -1412,8 +1041,6 @@ global int main(int argc,char** argv)
     memset(LocalPlayerName, 0, 16);
     strcpy(LocalPlayerName, "Anonymous");
 
-    // FIXME: Parse options before or after ccl?
-
     //
     //	Parse commandline
     //
@@ -1500,10 +1127,10 @@ global int main(int argc,char** argv)
 		continue;
 
 	    case 'F':
-		VideoFullScreen=1;
+                ForceFullScreen=1;
 		continue;
 	    case 'W':
-		VideoFullScreen=0;
+                ForceWindowed=1;
 		continue;
 	    case 'D':
 		VideoDepth=atoi(optarg);
@@ -1537,6 +1164,15 @@ global int main(int argc,char** argv)
     InitCcl();				// init CCL and load configurations!
     LoadCcl();
 
+    /* As explained above, this must be done *after* loading
+     * configuration from ccl files */
+
+    if (ForceFullScreen)
+         VideoFullScreen = 1;
+
+    if (ForceWindowed)
+         VideoFullScreen = 0;
+
     main1(argc,argv);
 
     return 0;
