@@ -106,9 +106,9 @@ UInt32	Sub_WavUnp13(UInt32,UInt32,UInt32,UInt32,UInt32);
 extern const unsigned char dcl_table[];
 local UInt8 *explode_buffer;
 
-extern const UInt8 wav_table[2512];
-extern const UInt32 small_tbl1[90];
-extern const UInt32 small_tbl2[32];
+static const UInt8 wav_table[2512];
+static const UInt32 small_tbl1[90];
+static const UInt32 small_tbl2[32];
 
 local UInt32 offset_mpq;		/// Offset to MPQ file data
 local UInt32 offset_htbl;		/// Offset to hash_table of MPQ
