@@ -278,9 +278,9 @@ local void ConvertREGM(const unsigned short* regm,int width,int height
 **		4 bytes header tag (TYPE )...
 **		long	length
 */
-local int PudReadHeader(CLFile* input,char* header,long* length)
+local int PudReadHeader(CLFile* input,char* header,int* length)
 {
-    long len;
+    int len;
 
     if( CLread(input,header,4)!=4 ) {
 	return 0;
@@ -334,7 +334,7 @@ local int PudReadByte(CLFile* input)
 global MapInfo* GetPudInfo(const char* pud)
 {
     CLFile* input;
-    long length;
+    int length;
     char header[5];
     char buf[1024];
     MapInfo* info;
@@ -482,7 +482,7 @@ global MapInfo* GetPudInfo(const char* pud)
 	    buf[0] = temp_short & 0xFF;
 	    buf[1] = (temp_short >> 8) & 0xFF;
 	    info->MapUID += ChksumArea(buf, 2);
-	    if( length<(long)sizeof(buf) ) {
+	    if( length<(int)sizeof(buf) ) {
 		bufp=buf;
 	    } else if( !(bufp=alloca(length)) ) {
 		perror("alloca()");
@@ -504,7 +504,7 @@ global MapInfo* GetPudInfo(const char* pud)
 	if( !memcmp(header,"ALOW",4) ) {
 	    char* bufp;
 
-	    if( length<(long)sizeof(buf) ) {
+	    if( length<(int)sizeof(buf) ) {
 		bufp=buf;
 	    } else if( !(bufp=alloca(length)) ) {
 		perror("alloca()");
@@ -531,7 +531,7 @@ global MapInfo* GetPudInfo(const char* pud)
 	    buf[0] = temp_short & 0xFF;
 	    buf[1] = (temp_short >> 8) & 0xFF;
 	    info->MapUID += ChksumArea(buf, 2);
-	    if( length<(long)sizeof(buf) ) {
+	    if( length<(int)sizeof(buf) ) {
 		bufp=buf;
 	    } else if( !(bufp=alloca(length)) ) {
 		perror("alloca()");
@@ -791,7 +791,7 @@ global MapInfo* GetPudInfo(const char* pud)
 global void LoadPud(const char* pud,WorldMap* map)
 {
     CLFile* input;
-    long length;
+    int length;
     char header[5];
     char buf[1024];
     int width;
@@ -972,7 +972,7 @@ global void LoadPud(const char* pud,WorldMap* map)
 		DebugLevel3("\tUsing default data\n");
 		CLseek(input,length,SEEK_CUR);
 	    } else {
-		if( length<(long)sizeof(buf) ) {
+		if( length<(int)sizeof(buf) ) {
 		    bufp=buf;
 		} else if( !(bufp=alloca(length)) ) {
 		    perror("alloca()");
@@ -993,7 +993,7 @@ global void LoadPud(const char* pud,WorldMap* map)
 	if( !memcmp(header,"ALOW",4) ) {
 	    char* bufp;
 
-	    if( length<(long)sizeof(buf) ) {
+	    if( length<(int)sizeof(buf) ) {
 		bufp=buf;
 	    } else if( !(bufp=alloca(length)) ) {
 		perror("alloca()");
@@ -1018,7 +1018,7 @@ global void LoadPud(const char* pud,WorldMap* map)
 		DebugLevel3("\tUsing default data\n");
 		CLseek(input,length,SEEK_CUR);
 	    } else {
-		if( length<(long)sizeof(buf) ) {
+		if( length<(int)sizeof(buf) ) {
 		    bufp=buf;
 		} else if( !(bufp=alloca(length)) ) {
 		    perror("alloca()");
