@@ -165,7 +165,9 @@ local int ChkReadWord(void)
 */
 local inline int ChkReadByte(void)
 {
-    return *((unsigned char*)chk_ptr)++;
+    int r = *((unsigned char*)chk_ptr);
+    chk_ptr = ((unsigned char*)chk_ptr) + 1;
+    return r;
 }
 
 /**
