@@ -232,11 +232,8 @@ local void SpellDeathCoilController(Missile * missile)
 		    && missile->TargetUnit->HP) {
 		if (missile->TargetUnit->HP <= 50) {
 		    source->Player->Score+=missile->TargetUnit->Type->Points;
-		    if( missile->TargetUnit->Type->Building ) {
-			source->Player->TotalRazings++;
-		    } else {
-			source->Player->TotalKills++;
-		    }
+                    source->Player->TotalKills++;
+
 #ifdef USE_HP_FOR_XP
 		    source->XP+=missile->TargetUnit->HP;
 #else
@@ -259,57 +256,11 @@ local void SpellDeathCoilController(Missile * missile)
 		}
 	    //
 	    //	No target unit -- try enemies in range 5x5
+	    //  And DeathCoil should be used only against a single
+	    //  organinc enemy. So, I'll not try to find enemies
+	    //  around.
 	    //
-	    } else {
-		int ec = 0;		// enemy count
-		int x = missile->DX / TileSizeX;
-		int y = missile->DY / TileSizeY;
 
-		n = SelectUnits(x - 2, y - 2, x + 2, y + 2, table);
-		if (n > 0) {
-		    // calculate organic enemy count
-		    for (i = 0; i < n; ++i) {
-			ec += (IsEnemy(source->Player, table[i])
-			       && table[i]->Type->Organic != 0);
-		    }
-		    if (ec > 0) {	// yes organic enemies found
-			for (i = 0; i < n; ++i) {
-			    if (IsEnemy(source->Player, table[i])
-				    && table[i]->Type->Organic != 0) {
-				// disperse damage between them
-				//NOTE: 1 is the minimal damage
-				if (table[i]->HP <= 50 / ec ) {
-				    source->Player->Score+=
-					    table[i]->Type->Points;
-				    if( missile->TargetUnit->Type->Building ) {
-					source->Player->TotalRazings++;
-				    } else {
-					source->Player->TotalKills++;
-				    }
-#ifdef USE_HP_FOR_XP
-				    source->XP+=table[i]->HP;
-#else
-				    source->XP+=table[i]->Type->Points;
-#endif
-				    ++source->Kills;
-				    table[i]->HP = 0;
-				    LetUnitDie(table[i]); // too much damage
-				} else {
-#ifdef USE_HP_FOR_XP
-				    source->XP += 50/ec;
-#endif
-				    table[i]->HP -= 50 / ec;
-				}
-			    }
-			}
-			if (source->Orders[0].Action!=UnitActionDie) {
-			    source->HP += 50;
-			    if (source->HP > source->Stats->HitPoints) {
-				source->HP = source->Stats->HitPoints;
-			    }
-			}
-		    }
-		}
 	    }
 	}
     }
