@@ -318,7 +318,7 @@
 extern char NameLine[];
 
 #ifndef FREECRAFT_LIB_PATH
-#define FREECRAFT_LIB_PATH "data"	/// Where to find the data files
+#define FREECRAFT_LIB_PATH "/usr/share/games/freecraft/default"	/// Where to find the data files
 #endif
 #ifndef FREECRAFT_HOME_PATH
 #define FREECRAFT_HOME_PATH ".freecraft"/// Data files in user home dir
