@@ -43,7 +43,7 @@
 #include "ui.h"
 
 #if defined(DEBUG) && defined(TIMEIT)
-#include "rdtsc.h"
+// #include "rdtsc.h"
 #endif
 
 /*----------------------------------------------------------------------------
@@ -217,6 +217,10 @@ global int IsTileVisible(const Player* player,int x,int y)
     int visiontype;
     int i;
 
+    if( (x < 0 || x >= TheMap.Width) || (y < 0 || y >= TheMap.Height) ) {
+	return 0;
+    }
+
     if( TheMap.Fields[y*TheMap.Width+x].Visible[player->Player]>1 ) {
 	return 2;
     }
