@@ -684,7 +684,7 @@ LISP errswitch(void)
 
 void err_stack(char *ptr __attribute__((unused)))
      /* The user could be given an option to continue here */
-{errl("the currently assigned stack limit has been exceded",NIL);}
+{errl("the currently assigned stack limit has been exceeded",NIL);}
 
 LISP stack_limit(LISP amount,LISP silent)
 {if NNULLP(amount)
@@ -1793,7 +1793,7 @@ LISP lapply(LISP fcn,LISP args)
     default:
       p = get_user_type_hooks(TYPE(fcn));
       if (p->leval)
-	return(errl("have eval, dont know apply",fcn));
+	return(errl("have eval, don't know apply",fcn));
       else
 	return(errl("cannot be applied",fcn));}}
 
