@@ -266,7 +266,7 @@ global void UpdateStats(int reset)
 }
 
     /// Macro to fetch an 8bit value, to have some looking 8/16/32 bit funcs.
-#define Fetch8(p)   (*((unsigned char*)(p))++)
+#define Fetch8(p)   (*((unsigned char*)(p))); p = ((unsigned char*)(p)) + 1
 
 /**
 **	Parse UDTA area from puds.
